package com.example.media_scanner_scan_file

import android.content.Intent
import android.net.Uri
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.io.File
import java.io.FileOutputStream
import java.io.IOException

class MediaScannerScanFilePlugin(private val registrar: Registrar): MethodCallHandler {

  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "media_scanner_scan_file")
      channel.setMethodCallHandler(MediaScannerScanFilePlugin(registrar))
    }
  }

  override fun onMethodCall(call: MethodCall, result: Result): Unit {
    when (call.method) {
        "scan" -> {
          val fileUri = call.argument<String>("fileUri") ?: return

          result.success(scan(fileUri))
        }
        else -> result.notImplemented()
    }

  }

  private fun scan(fileUri: String): HashMap<String, Any?> {
    val context = registrar.activeContext().applicationContext
    return try {
      val file = File(fileUri)
      val uri = Uri.fromFile(file)
      context.sendBroadcast(Intent(Intent.ACTION_MEDIA_SCANNER_SCAN_FILE, uri))
      SaveResultModel(uri.toString().isNotEmpty(), uri.toString(), null).toHashMap()
    } catch (e: IOException) {
      SaveResultModel(false, null, e.toString()).toHashMap()
    }
  }


}

class SaveResultModel (var isSuccess: Boolean,
                       var filePath: String? = null,
                       var errorMessage: String? = null) {
  fun toHashMap(): HashMap<String, Any?> {
    val hashMap = HashMap<String, Any?>()
    hashMap["isSuccess"] = isSuccess
    hashMap["filePath"] = filePath
    hashMap["errorMessage"] = errorMessage
    return hashMap
  }
}
